--------------------------------------------------------------------------------
-- Rubber Duck (weapon)
-- weapon for Carnage Contest
-- script by Kiffer-Opa
-- version 1.2
--------------------------------------------------------------------------------

-- Setup Tables
if kifferopa==nil then kifferopa={} end
kifferopa.duck={}
kifferopa.duck.duck={}

-- Load & Prepare Ressources
kifferopa.duck.gfx_wpn=loadgfx("weapons/rubberduck.png")		-- weapon image
setmidhandle(kifferopa.duck.gfx_wpn)
kifferopa.duck.gfx_icon=loadgfx("weapons/rubberduck_icon.png")		-- HUD icon
setmidhandle(kifferopa.duck.gfx_icon)
kifferopa.duck.sfx_attack=loadsfx("rubberduck1.ogg")		-- attack sound
kifferopa.duck.sfx_death=loadsfx("rubberduck2.ogg")
kifferopa.duck.sfx_water=loadsfx("rubberduck5.ogg")

--------------------------------------------------------------------------------
-- Weapon: duck
--------------------------------------------------------------------------------

kifferopa.duck.id=addweapon("kifferopa.duck","Rubber Duck",kifferopa.duck.gfx_wpn,2,1)			-- Add Weapon (2 uses, instantly)
kifferopa.duck.ammo=1

function kifferopa.duck.draw()													-- Draw
	-- Draw
	if weapon_shots<kifferopa.duck.ammo then
		--hudammobar(kifferopa.duck.ammo-weapon_shots,kifferopa.duck.ammo)
		if getplayeraction(0)==0 then
			setblend(blend_alpha)
			setalpha(1)
			setcolor(255,255,255)
			setscale(getplayerdirection(0),1)
			setrotation(getplayerdirection(0))
			drawimage(kifferopa.duck.gfx_wpn,getplayerx(0)+getplayerdirection(0)*7,getplayery(0)-1)
		end
	end
end

function kifferopa.duck.attack(attack)									-- Attack
	if weapon_timer>0 then
		weapon_timer=weapon_timer-1
	end
	
	if attack==1 then
		-- No more weapon switching!
		useweapon(0)
		weapon_mode=1
	end
	
	if weapon_shots<kifferopa.duck.ammo and weapon_timer<=0 and weapon_mode==1 then
		weapon_timer = 50
		-- Fire a projectile (on release/full charge)

		-- No more weapon switching!
		useweapon(0)
		-- Launch
		weapon_shots=weapon_shots+1
		id=createprojectile(kifferopa.duck.duck.id)
		projectiles[id]={}
		-- Ignore collision with current player at beginning
		projectiles[id].ignore=playercurrent()
		--
		projectiles[id].collide=false
		-- Set initial position of projectile
		projectiles[id].x=getplayerx(0)+getplayerdirection(0)*8
		projectiles[id].y=getplayery(0)
		if collision(col10x10, projectiles[id].x,projectiles[id].y,1,1,1)==1 then
			if terraincollision()==1 or objectcollision()>0 or playercollision()~=projectiles[id].ignore then
				projectiles[id].x=getplayerx(0)
			end
		end
		projectiles[id].px=projectiles[id].x
		projectiles[id].py=projectiles[id].y
		-- Set Speeds
		projectiles[id].sx=0
		projectiles[id].sy=0
		-- Set direction of projectile
		projectiles[id].dir=getplayerdirection(0)
		-- Set internal timer
		projectiles[id].timer=600
		-- Sound
		playsound(kifferopa.duck.sfx_attack)
	end
	if weapon_shots>=kifferopa.duck.ammo then
		endturn()
	end
end

--------------------------------------------------------------------------------
-- Projectile: duck
--------------------------------------------------------------------------------

kifferopa.duck.duck.id=addprojectile("kifferopa.duck.duck")		-- Add Projectile

function kifferopa.duck.duck.draw(id)					-- Draw
	-- Setup draw mode
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	setscale(1,1)
	-- Calculate projectile rotation
	if projectiles[id].dir==1 then
		setrotation(0)
	else
		setscale(1,-1)
		setrotation(180)
	end
	-- Draw projectile
	drawimage(kifferopa.duck.gfx_wpn,projectiles[id].x,projectiles[id].y-2)
	
	-- Draw Arrow if out of Screen
	outofscreenarrow(projectiles[id].x,projectiles[id].y)
end

function kifferopa.duck.duck.update(id)							-- Update
	
	-- Save old position (for rotation calculation)
	if getframesleft()%15==0 then
		projectiles[id].px=projectiles[id].x
		projectiles[id].py=projectiles[id].y
	end
	-- Timer
	projectiles[id].timer=projectiles[id].timer-1
	
	-- if duck is landed on water
	if (projectiles[id].y)>=getwatery()-46 then
		-- Move left/right, according to wind direction
		projectiles[id].x=projectiles[id].x+getwind()*25
	end
	if collision(col10x10 ,projectiles[id].x,projectiles[id].y,1,1,1)==1 then
		if terraincollision()==1 or objectcollision()>0 or playercollision()~=projectiles[id].ignore then
			projectiles[id].collide=true
		end
	else
		projectiles[id].ignore=0
	end
	-- Fall Down
	projectiles[id].sy=projectiles[id].sy+getgravity()*2
	msubt=math.ceil(math.abs(projectiles[id].sy)/3)
	msuby=projectiles[id].sy/msubt
	for i=1,msubt,1 do
		projectiles[id].y=projectiles[id].y+msuby
		-- Collision
		if collision(col10x10, projectiles[id].x,projectiles[id].y,1,1)==1 then
			if terraincollision()==1 or objectcollision()>0 or playercollision()~=projectiles[id].ignore then
				projectiles[id].sy=0
				projectiles[id].y=projectiles[id].y-msuby
				projectiles[id].collide=true
				break
			end
		else
			projectiles[id].ignore=0
		end
		-- Water (Swim)
		if (projectiles[id].y)>getwatery()-46 then
			local speed = math.sqrt(projectiles[id].sx^2+projectiles[id].sy^2)
			if speed>2 then
				particle(p_waterhit,projectiles[id].x,projectiles[id].y)
				playsound(kifferopa.duck.sfx_water)
			end
			if (speed>2 and speed<=3) then
				playsound(sfx_hitwater2)
			elseif (speed>3) then
				playsound(sfx_hitwater3)
			end
		
			projectiles[id].sy=0
			projectiles[id].y=getwatery()-46
			
		end
	end
	-- Timer / Explode
	if projectiles[id].collide==true or projectiles[id].timer<=0 then
		-- Cause damage
		arealdamage(projectiles[id].x,projectiles[id].y,105,45)
		-- Destroy terrain
		terrainexplosion(projectiles[id].x,projectiles[id].y,38,1)
		-- Crater
		grey=math.random(0,40)
		if math.random(0,1)==1 then
			terrainalphaimage(gfx_crater100,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,grey,grey,grey)
		else
			terrainalphaimage(gfx_crater125,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,grey,grey,grey)
		end
		playsound(kifferopa.duck.sfx_death)
		-- Free projectile
		freeprojectile(id)
	end
	scroll(projectiles[id].x,projectiles[id].y)
end
